FileTransferDTOInternal class

Constructors

FileTransferDTOInternal({String? content, String? fileName})
Returns a new FileTransferDTOInternal instance.

Properties

content String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
fileName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FileTransferDTOInternal?
Returns a new FileTransferDTOInternal instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FileTransferDTOInternal>
mapFromJson(dynamic json) Map<String, FileTransferDTOInternal>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FileTransferDTOInternal>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.