HomeAccountOptionsDTO class

Constructors

HomeAccountOptionsDTO({List<TicketCategoryDTO> categories = const [], List<TicketCategoryDTO> areas = const [], List<HomeAccountObjectDTO> objects = const [], List<HomeAccountObjectItemDTO> items = const []})
Returns a new HomeAccountOptionsDTO instance.

Properties

areas List<TicketCategoryDTO>
getter/setter pair
categories List<TicketCategoryDTO>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
items List<HomeAccountObjectItemDTO>
getter/setter pair
objects List<HomeAccountObjectDTO>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) HomeAccountOptionsDTO?
Returns a new HomeAccountOptionsDTO instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<HomeAccountOptionsDTO>
mapFromJson(dynamic json) Map<String, HomeAccountOptionsDTO>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<HomeAccountOptionsDTO>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.