TicketAttachmentDTOInternal class
Constructors
- TicketAttachmentDTOInternal({required int id, required int ticketId, required DateTime attachedAt, required String attachmentId, required String fileName, required String contentType, required int fileSize})
- Returns a new TicketAttachmentDTOInternal instance.
Properties
- attachedAt ↔ DateTime
-
getter/setter pair
- attachmentId ↔ String
-
getter/setter pair
- contentType ↔ String
-
getter/setter pair
- fileName ↔ String
-
getter/setter pair
- fileSize ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticketId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TicketAttachmentDTOInternal? -
Returns a new TicketAttachmentDTOInternal instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TicketAttachmentDTOInternal> -
mapFromJson(
dynamic json) → Map< String, TicketAttachmentDTOInternal> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TicketAttachmentDTOInternal> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.