TicketLifecycleMobileDTO class
Constructors
-
TicketLifecycleMobileDTO({List<
TicketMobileCommentDTO> comments = const [], List<HistoryEventDTO> history = const [], List<FileDTO> attachmentMetadata = const []}) - Returns a new TicketLifecycleMobileDTO instance.
Properties
-
attachmentMetadata
↔ List<
FileDTO> -
getter/setter pair
-
comments
↔ List<
TicketMobileCommentDTO> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
history
↔ List<
HistoryEventDTO> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TicketLifecycleMobileDTO? -
Returns a new TicketLifecycleMobileDTO instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TicketLifecycleMobileDTO> -
mapFromJson(
dynamic json) → Map< String, TicketLifecycleMobileDTO> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TicketLifecycleMobileDTO> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.