TicketListMobileDTO class

Constructors

TicketListMobileDTO({int? activeCount, int? inactiveCount, int? activeCreatedByMeCount, int? activeDueIn30Days, List<TicketMobileBaseDTO> list = const []})
Returns a new TicketListMobileDTO instance.

Properties

activeCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
activeCreatedByMeCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
activeDueIn30Days int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
inactiveCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
list List<TicketMobileBaseDTO>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TicketListMobileDTO?
Returns a new TicketListMobileDTO instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TicketListMobileDTO>
mapFromJson(dynamic json) Map<String, TicketListMobileDTO>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TicketListMobileDTO>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.