TicketMemberMobileDTO class

Constructors

TicketMemberMobileDTO({int? subjectId, String? subjectLabel, List<TicketMemberMobileDTORoleTypesEnum> roleTypes = const [], int? followerMemberId, List<TicketMemberAccountDTO> accounts = const []})
Returns a new TicketMemberMobileDTO instance.

Properties

accounts List<TicketMemberAccountDTO>
getter/setter pair
followerMemberId int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
roleTypes List<TicketMemberMobileDTORoleTypesEnum>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectId int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
subjectLabel String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TicketMemberMobileDTO?
Returns a new TicketMemberMobileDTO instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TicketMemberMobileDTO>
mapFromJson(dynamic json) Map<String, TicketMemberMobileDTO>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TicketMemberMobileDTO>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.