TicketMobileBaseDTO class

Constructors

TicketMobileBaseDTO({int? id, DateTime? createdAt, DateTime? modifiedAt, DateTime? closedAt, String? subject, String? description, TicketMobileBaseDTOTicketStateEnum? ticketState, List<String> possibleTicketStates = const [], TicketMobileBaseDTOTicketPriorityEnum? ticketPriority, DateTime? dueDate, String? ticketCategory, String? ticketArea, String? projectName, List<String> tags = const [], List<TicketMemberContactDTO> ticketMembersContactInfo = const [], List<TicketRelatedDTO> relations = const [], bool? privateTicket, bool? noComments, int? ticketMemberCount, bool? pinned})
Returns a new TicketMobileBaseDTO instance.

Properties

closedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
createdAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
dueDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
modifiedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
noComments bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
pinned bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
possibleTicketStates List<String>
getter/setter pair
privateTicket bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
projectName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
relations List<TicketRelatedDTO>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
tags List<String>
getter/setter pair
ticketArea String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketCategory String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketMemberCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketMembersContactInfo List<TicketMemberContactDTO>
getter/setter pair
ticketPriority TicketMobileBaseDTOTicketPriorityEnum?
getter/setter pair
ticketState TicketMobileBaseDTOTicketStateEnum?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TicketMobileBaseDTO?
Returns a new TicketMobileBaseDTO instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TicketMobileBaseDTO>
mapFromJson(dynamic json) Map<String, TicketMobileBaseDTO>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TicketMobileBaseDTO>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.