TicketMobileDTOInternal class

Constructors

TicketMobileDTOInternal({int? id, DateTime? createdAt, DateTime? modifiedAt, DateTime? closedAt, String? subject, String? description, TicketMobileDTOInternalTicketStateEnum? ticketState, List<String> possibleTicketStates = const [], TicketMobileDTOInternalTicketPriorityEnum? ticketPriority, DateTime? dueDate, String? ticketCategory, String? ticketArea, String? projectName, List<String> tags = const [], List<TicketMemberContactDTOInternal> ticketMembersContactInfo = const [], List<TicketRelatedDTOInternal> relations = const [], bool? privateTicket, bool? noComments, int? ticketMemberCount, bool? pinned, List<TicketRelatedDTOInternal> relatedEntities = const [], Map<String, List<ActionFeedbackDTOInternal>> actionTokens = const {}, List<ActionDTOInternal> actions = const [], List<TicketAttachmentDTOInternal> attachments = const [], bool? ignoreMemberCountWarning, List<ChecklistItemMobileDTOInternal> checklist = const [], List<TicketMobileBaseDTOInternal> subtickets = const [], CustomReminderSchemaDTOInternal? customReminderSchema})
Returns a new TicketMobileDTOInternal instance.

Properties

actions List<ActionDTOInternal>
getter/setter pair
actionTokens Map<String, List<ActionFeedbackDTOInternal>>
getter/setter pair
attachments List<TicketAttachmentDTOInternal>
getter/setter pair
checklist List<ChecklistItemMobileDTOInternal>
getter/setter pair
closedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
createdAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
customReminderSchema CustomReminderSchemaDTOInternal?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
dueDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ignoreMemberCountWarning bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
modifiedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
noComments bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
pinned bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
possibleTicketStates List<String>
getter/setter pair
privateTicket bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
projectName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
relatedEntities List<TicketRelatedDTOInternal>
getter/setter pair
relations List<TicketRelatedDTOInternal>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
subtickets List<TicketMobileBaseDTOInternal>
getter/setter pair
tags List<String>
getter/setter pair
ticketArea String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketCategory String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketMemberCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
ticketMembersContactInfo List<TicketMemberContactDTOInternal>
getter/setter pair
ticketPriority TicketMobileDTOInternalTicketPriorityEnum?
getter/setter pair
ticketState TicketMobileDTOInternalTicketStateEnum?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TicketMobileDTOInternal?
Returns a new TicketMobileDTOInternal instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TicketMobileDTOInternal>
mapFromJson(dynamic json) Map<String, TicketMobileDTOInternal>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TicketMobileDTOInternal>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.