toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'TicketMobileWithLastCommentDTO[id=$id, createdAt=$createdAt, modifiedAt=$modifiedAt, closedAt=$closedAt, subject=$subject, description=$description, ticketState=$ticketState, possibleTicketStates=$possibleTicketStates, ticketPriority=$ticketPriority, dueDate=$dueDate, ticketCategory=$ticketCategory, ticketArea=$ticketArea, projectName=$projectName, tags=$tags, ticketMembersContactInfo=$ticketMembersContactInfo, relations=$relations, privateTicket=$privateTicket, noComments=$noComments, ticketMemberCount=$ticketMemberCount, pinned=$pinned, lastCommentText=$lastCommentText, lastCommentAuthorSubjectId=$lastCommentAuthorSubjectId, lastCommentAuthor=$lastCommentAuthor, lastCommentCreatedAt=$lastCommentCreatedAt, allCommentAuthorSubjectIds=$allCommentAuthorSubjectIds, allCommentAuthorRelationshipIds=$allCommentAuthorRelationshipIds]';